#!/usr/bin/perl

# Version 1.0
# Script to dump Calibration and EEPROM data from Fluke 45 meter
# http://photonicsguy.ca/reference/fluke45


use Device::SerialPort;
use warnings;


$SERIALPORT='/dev/ttyUSB0';

# Set up the serial port
# 9600,8N1 on the USB ftdi driver
my $port = Device::SerialPort->new($SERIALPORT);
$port->databits(8);
$port->baudrate(9600);
$port->parity("none");
$port->stopbits(1);

$port->are_match("\n","\r");    # possible end strings<S-Del>

# Record Seperator
$sp=",";
#$sp=":\t";
$port->lookclear;


$idn=fluke_command("*idn?");
($man,$model,$serial,$version)=split(/,/,$idn);
print "Calibration dump$sp".localtime()."\n";
print "Port$sp$SERIALPORT\n";
print "Model$sp$man $model\n";
print "Serial$sp$serial\n";
print "Version$sp$version\n\n\n";
print "Calibration constants (CALCONST 1-33)\n";
for($i=1;$i<=33;$i++) {
print "$i$sp";
print fluke_command("calconst? $i");
print "\n";
}
print "\n\nEEPROM registers (EEREG 1-64)\n";
for($i=1;$i<=64;$i++) {
print "$i$sp";
print fluke_command("eereg? $i");
print "\n";
}

sub fluke_command {
	my $cmd=$_[0];
	$port->write($cmd."\r");
	$port->lookclear;
	my $gotit = "";
while(1) {
  until ("" ne $gotit) {
      $gotit = $port->lookfor;       # poll until data ready
      die "Aborted without match\n" unless (defined $gotit);
  }
#print "\n\n";
#print "===================================\n";
#print printable($gotit);
#print "\n";
#print "===================================\n";

if($gotit eq uc($cmd)) {
	#print "ECHO";
	$gotit="";
}
elsif($gotit eq "=>") {
	#print "PRMPT";
	$gotit="";
}
else {
return $gotit;
}
}
}
